@@ -1,7 +1,6 @@
-use assert_cmd::prelude::*;
+use assert_cmd::{cargo, Command};
 use std::ffi::OsStr;
 use std::path::Path;
-use std::process::Command;
 
 pub fn binary() -> CargoGenerateArgBuilder {
     CargoGenerateArgBuilder::new()
@@ -11,7 +10,7 @@ pub struct CargoGenerateArgBuilder(Command);
 
 impl CargoGenerateArgBuilder {
     pub fn new() -> Self {
-        let mut builder = Self(Command::cargo_bin(env!("CARGO_PKG_NAME")).unwrap());
+        let mut builder = Self(cargo::cargo_bin_cmd!());
         builder.0.arg("generate");
 
         builder
@@ -22,6 +21,16 @@ impl CargoGenerateArgBuilder {
         self.arg("--init")
     }
 
+    /// wrapper for `--allow-commands` cli flag
+    pub fn flag_allow_commands(&mut self) -> &mut Self {
+        self.arg("--allow-commands")
+    }
+
+    /// wrapper for `--no-workspace` cli flag
+    pub fn flag_no_workspace(&mut self) -> &mut Self {
+        self.arg("--no-workspace")
+    }
+
     /// wrapper for `--name <name>` cli argument
     pub fn arg_name(&mut self, name: impl AsRef<OsStr>) -> &mut Self {
         self.arg("--name").arg(name)
